
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.71'
version = '1.2.71'
full_version = '1.2.71'
git_revision = 'f0c1aaf69fc10e6094feb6fb012f73e9d5c0b25b'
release = True

if not release:
    version = full_version
    short_version += ".dev"
